<?php 

class RepartitionCours extends CI_Controller{

	public function __construct()
	{
		parent::__construct();
		$this->load->model("ExerciceModel","exercice");
		$this->load->model("TermModel","term");
		$this->load->model("EnseignantModel","enseignant");
		$this->load->model("SalleModel","salle");
		$this->load->model("ClasseModel","classe");
		$this->load->model("NiveauModel","niveau");
		$this->load->model("HoraireCoursModel","horaire");
		$this->load->model("RepartitionCoursModel","repartition");

	}

	public function index($action="create",$values=null)
	{
		$data["active"] = 1;
		$data["action"] = $action;
		$data["lists"] = $this->repartition->getAll();

		$exercices = $this->exercice->getAll();
		$data["exercices"] = $exercices;
		$data["terms"] = [];
		
		if(count($exercices))
		{
			$data["terms"] = $this->term->getAllByExercice($exercices[0]->idExercice);
		}

		$data["enseignants"] = $this->enseignant->getAll();
		$data["salles"] = $this->salle->getAll();
		
		$classes = $this->classe->getAll();
		$niveaux = [];
		$days = []; // jours de cours
		$data["classes"] = $classes;
		$data["niveaux"] = [];

		if(count($classes))
		{
			$niveaux = $this->niveau->getByClasse($classes[0]->idClasse);
		}

		if(count($niveaux))
		{
			$days = explode("|", $niveaux[0]->joursCours);
		}

		if($values)
		{
			$data["values"] = $values;
		}
		
		$data["horaires"] = $this->horaire->getAll();
		$data["niveaux"] = $niveaux;
		$data["days"] = $days;

		$this->load->view("inscription/repartitionCours",$data);
	}

	public function getNiveauAndJours()
	{
		$idClasse = (int)$_POST["idClasse"];
		$niveaux = $this->niveau->getByClasse($idClasse);
		$days = [];
		$data["template"] = true;

		if(count($niveaux))
		{
			$days = explode("|", $niveaux[0]->joursCours);
		}

		$data["niveaux"] = $niveaux;
		$data["days"] = $days;
		$this->load->view("inscription/components/niveau_and_jours_repartition",$data);
	}

	public function resetForm($action="create",$values=null)
	{
		$data["active"] = 1;
		$data["action"] = $action;
		$data["lists"] = $this->repartition->getAll();

		$exercices = $this->exercice->getAll();
		$data["exercices"] = $exercices;
		$data["terms"] = $this->term->getAllByExercice((int)$values["exercice"]);

		$data["enseignants"] = $this->enseignant->getAll();
		$data["salles"] = $this->salle->getAll();
		
		$classes = $this->classe->getAll();
		$data["classes"] = $classes;
		$data["niveaux"] = $this->niveau->getByClasse((int)$values["classe"]);
		
		$data["horaires"] = $this->horaire->getAll();

		$data["days"] = [];
		if(!empty($data["niveaux"]))
		{
			$data["days"] = explode("|",$data["niveaux"][0]->joursCours);
		}

		$data["values"] = $values;

		$this->load->view("inscription/repartitionCours",$data);
	}

	public function create()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules("exercice","exercice","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("term","term","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("enseignant","enseignant","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("salle","salle","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("classe","classe","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("niveau","niveau","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("horaire","horaire","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("jours","jours","required",["required" => "Ce champ est obligatoire"]);
		if(!$this->form_validation->run())
		{
			$this->resetForm("create",$_POST);
			return false;
		}

		$exercice = (int)$_POST["exercice"];
		$term = (int)$_POST["term"];
		$enseignant = trim($_POST["enseignant"]);
		$salle = (int)$_POST["salle"];
		$classe = (int)$_POST["classe"];
		$niveau = (int)$_POST["niveau"];
		$horaire = (int)$_POST["horaire"];
		$jours = trim($_POST["jours"]);

		/**
		 * Test enseignant occupé
		 * 
		 * */
		if($this->repartition->enseignantOccupe($enseignant,$horaire,$jours,$term))
		{
			$this->resetForm("create",array_merge($_POST,Utility::getAlert("error","Enseignant occupé à ce creneau")));
			return false;
		}

		/**
		 * Test salle occupé
		 * 
		 * */
		if($this->repartition->salleOccupe($salle,$horaire,$jours,$term))
		{
			$this->resetForm("create",array_merge($_POST,Utility::getAlert("error","Salle occupé à ce creneau")));
			return false;
		}

		$this->repartition->create(["idTerm","matriculeEnseignant","idClasse","idSalle","idNiveau","jours","idHoraireCours"],[$term,$enseignant,$classe,$salle,$niveau,$jours,$horaire]);

		$this->index("create",Utility::getAlert("success"));
	}

	public function getOne()
	{
		$id = (int)$_POST["id"];
		$res = $this->repartition->getOne($id);

		$this->resetForm("update",[
			"id" => $res->idRepartitionCours,
			"term" => $res->idTerm,
			"enseignant" => $res->matriculeEnseignant,
			"salle" => $res->idSalle,
			"classe" => $res->idClasse,
			"niveau" => $res->idNiveau,
			"horaire" => $res->idHoraireCours,
			"jours" => $res->jours,
			"exercice" => $res->idExercice
		]);
	}

	public function update()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules("exercice","exercice","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("term","term","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("enseignant","enseignant","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("salle","salle","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("classe","classe","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("niveau","niveau","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("horaire","horaire","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("jours","jours","required",["required" => "Ce champ est obligatoire"]);
		if(!$this->form_validation->run())
		{
			$this->resetForm("update",$_POST);
			return false;
		}

		$exercice = (int)$_POST["exercice"];
		$term = (int)$_POST["term"];
		$enseignant = trim($_POST["enseignant"]);
		$salle = (int)$_POST["salle"];
		$classe = (int)$_POST["classe"];
		$niveau = (int)$_POST["niveau"];
		$horaire = (int)$_POST["horaire"];
		$jours = trim($_POST["jours"]);
		$id = (int)$_POST['id'];

		$toUpdate = $this->repartition->getOne($id);
		
		if($enseignant !== $toUpdate->matriculeEnseignant)
		{
			if($this->repartition->enseignantOccupe($enseignant,$horaire,$jours,$term))
			{
				$this->resetForm("update",array_merge($_POST,Utility::getAlert("error","Enseignant occupé à ce creneau")));
				return false;
			}
		}
		if($salle !== (int)$toUpdate->idSalle)
		{
			if($this->repartition->salleOccupe($salle,$horaire,$jours,$term))
			{
				$this->resetForm("update",array_merge($_POST,Utility::getAlert("error","Salle occupé à ce creneau")));
				return false;
			}
		}

		$this->repartition->update(["idTerm","matriculeEnseignant","idClasse","idSalle","idNiveau","jours","idHoraireCours"],[$term,$enseignant,$classe,$salle,$niveau,$jours,$horaire,$id]);

		$this->index("create",Utility::getAlert("success"));
	}

	public function delete()
	{
		$id = (int)$_POST["id"];

		$this->repartition->delete($id);
		$this->index("create",Utility::getAlert("success","Repartition supprimé"));
	}

	public function filter()
	{
		$query = trim($_POST["query"]);
		if($query === "")
		{
			$this->index();
			return false;
		}

		$data["active"] = 1;
		$data["action"] = "create";
		$data["lists"] = $this->repartition->getAllSearch("%".$query."%");

		$exercices = $this->exercice->getAll();
		$data["exercices"] = $exercices;
		$data["terms"] = [];
		
		if(count($exercices))
		{
			$data["terms"] = $this->term->getAllByExercice($exercices[0]->idExercice);
		}

		$data["enseignants"] = $this->enseignant->getAll();
		$data["salles"] = $this->salle->getAll();
		
		$classes = $this->classe->getAll();
		$niveaux = [];
		$days = []; // jours de cours
		$data["classes"] = $classes;
		$data["niveaux"] = [];

		if(count($classes))
		{
			$niveaux = $this->niveau->getByClasse($classes[0]->idClasse);
		}

		if(count($niveaux))
		{
			$days = explode("|", $niveaux[0]->joursCours);
		}

		$data["query"] = $query;
		
		$data["horaires"] = $this->horaire->getAll();
		$data["niveaux"] = $niveaux;
		$data["days"] = $days;

		$this->load->view("inscription/repartitionCours",$data);

	}

	public function export()
	{
		$all = $this->repartition->getAll();
		$data = [];

		foreach ($all as $value) {
			$data[] = (object)[
				"Session" => $value->anneeExercice . " - " . $value->nomTerm,
				"Classe" => $value->codeClasse,
				"Niveau" => $value->codeNiveau,
				"Jours cours" => $value->jours,
				"Horaire" => $value->debutCours,
				"Salle" => $value->nomSalle,
				"Capacité salle" => $value->capaciteSalle,
				"Enseignant" => $value->nomEnseignant . " " . $value->prenomEnseignant
			];
		}
		ExportExcel::exporter('repartition', $data);
	}



}