<?php 

class Niveau extends CI_Controller{

	public function __construct()
	{
		parent::__construct();
		$this->load->model("NiveauModel","niveau");
		$this->load->model("ClasseModel","classe");
		$this->load->model("JoursCoursModel","jours");
	}

	public function index($action="create",$values=null)
	{
		$data["active"] = 2;
		$data["action"] = $action;
		$data["lists"] = $this->niveau->getAll();

		$data["classes"] = $this->classe->getAll();
		$data["days"] = $this->jours->getAll();

		if($values)
		{
			$data["values"] = $values;
		}

		$this->load->view("parametrage/niveau",$data);
	}

	public function create()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules('code',"code","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules('degree',"degree","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules('classe',"classe","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules('ordre',"ordre","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules('categorie',"categorie","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("jours[]","jours","required",["required" => "Vous devez selectionner aux mois une"]);

		if(!$this->form_validation->run())
		{
			$this->index("create",$_POST);
			return false;
		}

		$this->form_validation->set_rules("degree","degree","callback_degree_exist");
		$this->form_validation->set_rules("code","code","callback_code_exist");
		
		if(!$this->form_validation->run())
		{
			$this->index("create",$_POST);
			return false;
		}

		$code = trim($_POST["code"]);
		$degree = (int)$_POST["degree"];
		$classe = (int)$_POST["classe"];
		$ordre = (int)$_POST["ordre"];
		$categorie = (int)$_POST["categorie"];
		$description = trim($_POST["description"]);
		$jours = $_POST['jours'];

		$dayCours = "";
		foreach($jours as $jour)
		{
			$dayCours .= $jour . "|";
		}

		$dayCours .= "Online";

		$this->niveau->create(["codeNiveau","degreeNiveau","idClasse","ordrePriorite",'categorie',"joursCours","description"],[$code,$degree,$classe,$ordre,$categorie,$dayCours,$description]);
		$this->index("create",array_merge(Utility::getAlert("success"),["classe" => trim($_POST['classe'])]));
		
	}

	public function getOne()
	{
		$id = (int)$_POST["id"];
		$res = $this->niveau->getOne($id);

		$this->index("update",[
			"id" => $res->idNiveau,
			"code" => $res->codeNiveau,
			"degree" => $res->degreeNiveau,
			"classe" =>$res->idClasse,
			"ordre" => $res->ordrePriorite,
			"categorie" => $res->categorie,
			"jours" => explode("|", $res->joursCours),
			"description" => $res->description
		]);
	}

	public function update()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules('code',"code","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules('degree',"degree","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules('classe',"classe","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules('ordre',"ordre","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules('categorie',"categorie","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("jours[]","jours","required",["required" => "Vous devez selectionner aux mois une"]);

		if(!$this->form_validation->run())
		{
			$this->index("update",$_POST);
			return false;
		}

		$id = (int)$_POST["id"];
		$code = trim($_POST["code"]);
		$degree = (int)$_POST["degree"];
		$classe = (int)$_POST["classe"];
		$ordre = (int)$_POST["ordre"];
		$categorie = (int)$_POST["categorie"];
		$description = trim($_POST["description"]);
		$jours = $_POST['jours'];

		$dayCours = "";
		foreach($jours as $jour)
		{
			$dayCours .= $jour . "|";
		}

		$dayCours .= "Online";

		$toUpdate = $this->niveau->getOne($id);

		if($degree !== (int)$toUpdate->degreeNiveau || $classe !== (int)$toUpdate->idClasse)
		{
			$this->form_validation->set_rules("degree","degree","callback_degree_exist");
			if(!$this->form_validation->run())
			{
				$this->index("update",$_POST);
				return false;
			}
		}
		if($code !== $toUpdate->codeNiveau || $classe !== (int)$toUpdate->idClasse)
		{
			$this->form_validation->set_rules("code","code","callback_code_exist");
			if(!$this->form_validation->run())
			{
				$this->index("update",$_POST);
				return false;
			}
		}

		$this->niveau->update(["codeNiveau","degreeNiveau","idClasse","ordrePriorite","categorie","joursCours","description"],[$code,$degree,$classe,$ordre,$categorie,$dayCours,$description,$id]);
		$this->index("create",Utility::getAlert("success"));


	}

	public function delete()
	{
		$id = (int)$_POST["id"];
		$this->niveau->delete($id);
		$this->index("create",Utility::getAlert("success","Niveau supprimé"));
	}

	public function filter()
	{
		$query = trim($_POST["query"]);
		if($query === "")
		{
			$this->index("create");
			return false;
		}

		$data["active"] = 2;
		$data["action"] = "create";
		$data["lists"] = $this->niveau->getAllSearch("%".$query."%");

		$data["classes"] = $this->classe->getAll();
		$data["days"] = $this->jours->getAll();

		$data["query"] = $query;

		$this->load->view("parametrage/niveau",$data);

	}



	/***
	 * 
	 * Form validation
	 * 
	 * */
	public function degree_exist($degree)
	{
		if($this->niveau->degreeExist((int)$_POST["classe"],(int)$_POST["degree"]))
		{
			$this->form_validation->set_message('degree_exist', 'Degrée existant pour cette classe');
            return FALSE;
		}
		else
		{
			return true;
		}
	}
	public function code_exist($code)
	{
		if($this->niveau->codeExist((int)$_POST["classe"],trim($_POST["code"])))
		{
			$this->form_validation->set_message('code_exist', 'Code existant pour cette classe');
            return FALSE;
		}
		else
		{
			return true;
		}
	}


}