<?php 

class CSession extends CI_Controller{

	public function __construct()
	{
		parent::__construct();
		$this->load->model("SessionModel","msession");
		$this->load->model("ExerciceModel","exercice");
		$this->load->model("TermModel","term");
	}

	public function index($action="create",$values=null)
	{
		$data["active"] = 1;
		$data["action"] = $action;
		$data["lists"] = $this->msession->getAll();

		$exercices = $this->exercice->getAll();
		$data["exercices"] = $exercices;

		$data["terms"] = [];
		if(count($exercices))
		{
			$data["terms"] = $this->term->getAllByExercice($exercices[0]->idExercice);
		}

		if($values)
		{
			$data["values"] = $values;
		}
		

		$this->load->view("test/session",$data);
	}

	/**
	 * REnvoi formulaire prerempli
	 * 
	 * */
	public function refreshForm($action="create",$values=null)
	{
		$data["active"] = 1;
		$data["action"] = $action;
		$data["lists"] = $this->msession->getAll();

		$data["exercices"] = $this->exercice->getAll();


		$data["terms"] = $this->term->getAllByExercice((int)$values["exercice"]);

		if($values)
		{
			$data["values"] = $values;
		}
		

		$this->load->view("test/session",$data);
	}

	public function create()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules("exercice","exercice","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("term","term","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("droit","droit","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("date-resultat","date-resultat","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("date-inscription","date-inscription","required",["required" => "Ce champ est obligatoire"]);

		if(!$this->form_validation->run())
		{
			$this->refreshForm("create",$_POST);
			return false;
		}

		$exercice = (int)$_POST["exercice"];
		$term = (int)$_POST["term"];
		$droit = (int)$_POST["droit"];
		$dateInscription = trim($_POST['date-inscription']);
		$dateResultat = trim($_POST["date-resultat"]);

		if($this->msession->isExist($term))
		{
			$this->refreshForm("create",array_merge($_POST,Utility::getAlert("error","Session déjà enregistré")));
			return false;
		}

		$this->msession->create(["idTerm","droitSession","dateInscription","dateResultat"],[$term,$droit,$dateInscription,$dateResultat]);
		$this->index("create",Utility::getAlert("success"));

	}

	public function getOne()
	{
		$id = (int)$_POST["id"];
		$res = $this->msession->getOne($id);

		$this->refreshForm("update",[
			"id" => $res->idSession,
			"term" => $res->idTerm,
			"exercice" => $res->idExercice,
			"droit" => $res->droitSession,
			"date-inscription" => $res->dateInscription,
			"date-resultat" => $res->dateResultat
		]);
	}

	public function update()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules("droit","droit","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("date-resultat","date-resultat","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("date-inscription","date-inscription","required",["required" => "Ce champ est obligatoire"]);

		$id = (int)$_POST["id"];

		if(!$this->form_validation->run())
		{
			$res = $this->msession->getOne($id);
			$this->refreshForm("update",[
				"id" => $res->idSession,
				"term" => $res->idTerm,
				"exercice" => $res->idExercice,
				"droit" => $res->droitSession,
				"date-inscription" => $res->dateInscription,
				"date-resultat" => $res->dateResultat
			]);
			return false;
		}

		$droit = (int)$_POST["droit"];
		$dateInscription = trim($_POST['date-inscription']);
		$dateResultat = trim($_POST["date-resultat"]);



		$this->msession->update(["droitSession","dateInscription","dateResultat"],[$droit,$dateInscription,$dateResultat,$id]);
		$this->index("create",Utility::getAlert("success"));	
	}

	public function delete()
	{
		$id = (int)$_POST["id"];
		$this->msession->delete($id);
		$this->index("create",Utility::getAlert("success","Session supprimé"));
	}

	public function filter()
	{
		$query = trim($_POST["query"]);
		if($query === "")
		{
			$this->index();
			return false;
		}

		$data["active"] = 1;
		$data["action"] = "create";
		$data["lists"] = $this->msession->getAllSearch("%".$query."%");

		$exercices = $this->exercice->getAll();
		$data["exercices"] = $exercices;

		$data["terms"] = [];
		if(count($exercices))
		{
			$data["terms"] = $this->term->getAllByExercice($exercices[0]->idExercice);
		}

		$data["query"] = $query;
		

		$this->load->view("test/session",$data);
	}


	/**
	 * Changer les valeur du select term lorsque l'exercice change
	 * 
	 * */
	public function getTerm()
	{
		$idExercice = (int)$_POST["idExercice"];
		$data["terms"] = $this->term->getAllByExercice($idExercice);
		$this->load->view("test/components/term_session",$data);
	}

}