<?php 

class RepartitionCoursModel extends CI_Model{

	public function getAll()
	{
		return DB::customQuery("SELECT * FROM repartitionCours
			INNER JOIN term ON term.idTerm=repartitionCours.idTerm
			INNER JOIN exercice ON exercice.idExercice=term.idExercice
			INNER JOIN enseignant ON enseignant.matriculeEnseignant=repartitionCours.matriculeEnseignant
			INNER JOIN classe ON classe.idClasse=repartitionCours.idClasse
			INNER JOIN niveau ON niveau.idNiveau=repartitionCours.idNiveau
			INNER JOIN horaireCours ON horaireCours.idHoraireCours=repartitionCours.idHoraireCours
			INNER JOIN salle ON salle.idSalle=repartitionCours.idSalle
			ORDER BY exercice.anneeExercice DESC,idRepartitionCours DESC");
	}
	public function getAllSearch($query)
	{
		return DB::customQuery("SELECT * FROM repartitionCours
			INNER JOIN term ON term.idTerm=repartitionCours.idTerm
			INNER JOIN exercice ON exercice.idExercice=term.idExercice
			INNER JOIN enseignant ON enseignant.matriculeEnseignant=repartitionCours.matriculeEnseignant
			INNER JOIN classe ON classe.idClasse=repartitionCours.idClasse
			INNER JOIN niveau ON niveau.idNiveau=repartitionCours.idNiveau
			INNER JOIN horaireCours ON horaireCours.idHoraireCours=repartitionCours.idHoraireCours
			INNER JOIN salle ON salle.idSalle=repartitionCours.idSalle
			WHERE exercice.anneeExercice LIKE ?
			OR term.nomTerm LIKE ?
			OR enseignant.matriculeEnseignant LIKE ?
			OR enseignant.nomEnseignant LIKE ?
			OR enseignant.prenomEnseignant LIKE ?
			OR salle.nomSalle LIKE ?
			OR classe.codeClasse LIKE ?
			OR niveau.codeNiveau LIKE ?
			ORDER BY exercice.anneeExercice DESC,idRepartitionCours DESC",
			[$query,$query,$query,$query,$query,$query,$query,$query]
		);
	}

	/**
	 * Selection repartition salle pour afficher à l'onglet occupation salle
	 * 
	 * */
	public function getOccupations()
	{
		$res = DB::customQuery("SELECT MAX(idTerm) AS max FROM repartitionCours",[],false);
		if(!$res)
		{
			return [];
		}
		
		return DB::customQuery("SELECT * FROM repartitionCours
			INNER JOIN term ON term.idTerm=repartitionCours.idTerm
			INNER JOIN exercice ON exercice.idExercice=term.idExercice
			INNER JOIN enseignant ON enseignant.matriculeEnseignant=repartitionCours.matriculeEnseignant
			INNER JOIN classe ON classe.idClasse=repartitionCours.idClasse
			INNER JOIN niveau ON niveau.idNiveau=repartitionCours.idNiveau
			INNER JOIN horaireCours ON horaireCours.idHoraireCours=repartitionCours.idHoraireCours
			INNER JOIN salle ON salle.idSalle=repartitionCours.idSalle
			WHERE repartitionCours.idTerm = ?
			ORDER BY exercice.anneeExercice DESC,idRepartitionCours DESC",
			[$res->max]
		);
	}
	/**
	 * Recuperer information salle: capacite et occupation
	 * 
	 * 
	 * */

	public function getOccupation($term,$niveau,$horaire,$jours,$idSalle)
	{
		return DB::customQuery("SELECT repartitionCours.occupation,salle.capaciteSalle
			FROM repartitionCours
			INNER JOIN salle ON salle.idSalle=repartitionCours.idSalle
			WHERE repartitionCours.idTerm=?
			AND repartitionCours.idNiveau=?
			AND repartitionCours.idHoraireCours=?
			AND repartitionCours.jours=?
			AND repartitionCours.idSalle=?",
			[$term,$niveau,$horaire,$jours,$idSalle],false
		);
	}

	public function getOccupationsSearch($query)
	{
		$res = DB::customQuery("SELECT MAX(idTerm) AS max FROM repartitionCours",[],false);
		if(!$res)
		{
			return [];
		}
		
		return DB::customQuery("SELECT * FROM repartitionCours
			INNER JOIN term ON term.idTerm=repartitionCours.idTerm
			INNER JOIN exercice ON exercice.idExercice=term.idExercice
			INNER JOIN enseignant ON enseignant.matriculeEnseignant=repartitionCours.matriculeEnseignant
			INNER JOIN classe ON classe.idClasse=repartitionCours.idClasse
			INNER JOIN niveau ON niveau.idNiveau=repartitionCours.idNiveau
			INNER JOIN horaireCours ON horaireCours.idHoraireCours=repartitionCours.idHoraireCours
			INNER JOIN salle ON salle.idSalle=repartitionCours.idSalle
			WHERE repartitionCours.idTerm = ?
			AND (exercice.anneeExercice LIKE ?
			OR term.nomTerm LIKE ?
			OR enseignant.matriculeEnseignant LIKE ?
			OR enseignant.nomEnseignant LIKE ?
			OR enseignant.prenomEnseignant LIKE ?
			OR salle.nomSalle LIKE ?
			OR classe.codeClasse LIKE ?
			OR niveau.codeNiveau LIKE ?)
			ORDER BY exercice.anneeExercice DESC,idRepartitionCours DESC",
			[$res->max,$query,$query,$query,$query,$query,$query,$query,$query]
		);
	}

	public function getOne($id)
	{
		return DB::customQuery("SELECT * FROM repartitionCours
			INNER JOIN term ON term.idTerm=repartitionCours.idTerm
			INNER JOIN exercice ON exercice.idExercice=term.idExercice
			WHERE idRepartitionCours=?",
			[$id],false
		);
	}
	public function create($fields,$values)
	{
		DB::insert("repartitionCours")
			->parametters($fields)
			->execute($values);
	}

	public function update($fields,$values)
	{
		DB::update("repartitionCours")
			->parametters($fields)
			->where("idRepartitionCours","=")
			->execute($values);
	}

	public function delete($id)
	{
		DB::delete("repartitionCours")
			->where("idRepartitionCours","=")
			->execute([$id]);
	}

	/**
	 * Verification occupation enseignant
	 * 
	 * */
	public function enseignantOccupe($matricule,$horaire,$jours,$term)
	{
		$res = DB::select("repartitionCours")
					->where("matriculeEnseignant","=")
					->and("idHoraireCours","=")
					->and("jours","=")
					->and("idTerm","=")
					->fetchOne([$matricule,$horaire,$jours,$term]);
		if($res)
			return true;
		return false;
	}

	/**
	 * Verification occupation enseignant
	 * 
	 * */
	public function salleOccupe($salle,$horaire,$jours,$term)
	{
		$res = DB::select("repartitionCours")
					->where("idSalle","=")
					->and("idHoraireCours","=")
					->and("jours","=")
					->and("idTerm","=")
					->fetchOne([$salle,$horaire,$jours,$term]);
		if($res)
			return true;
		return false;
	}

	/**
	 * Recherche horaires disponible via jours,term,niveau
	 * 
	 * */
	public function findHoraires($jours,$niveau,$term)
	{
		return DB::customQuery("SELECT horaireCours.* FROM repartitionCours
			INNER JOIN horaireCours ON horaireCours.idHoraireCours=repartitionCours.idHoraireCours
			WHERE jours=?
			AND idNiveau=?
			AND idTerm=?
			GROUP BY idHoraireCours",
			[$jours,$niveau,$term]
		);
	}

	/**
	 * Recherche horaires disponible via jours,term,niveau et horaire
	 * 
	 * */
	public function findSalles($jours,$niveau,$term,$horaire)
	{
		return DB::customQuery("SELECT salle.* FROM repartitionCours
			INNER JOIN salle ON salle.idSalle=repartitionCours.idSalle
			WHERE jours=?
			AND idNiveau=?
			AND idTerm=?
			AND idHoraireCours=?",
			[$jours,$niveau,$term,$horaire]
		);
	}

	/**
	 * 
	 * Mise à jour occupation salle
	 * 
	 * */
	public function updateOccupation($term,$horaire,$jours,$salle,$niveau, $n = 1)
	{
		if ($n > 0) 
		{
			DB::customQuery("UPDATE repartitionCours SET occupation = occupation+1 
				WHERE idTerm=?
				AND idHoraireCours=?
				AND jours=?
				AND idSalle=?
				AND idNiveau=?",
				[$term,$horaire,$jours,$salle,$niveau]
			);
		} 
		else 
		{
			DB::customQuery("UPDATE repartitionCours SET occupation = occupation-1 
				WHERE idTerm=?
				AND idHoraireCours=?
				AND jours=?
				AND idSalle=?
				AND idNiveau=?",
				[$term,$horaire,$jours,$salle,$niveau]
			);
		}
	}

	/**
	 * 
	 * Mise à jour occupation salle via id
	 * 
	 * */
	public function updateOccupationById($id, $n = 1)
	{
		if ($n > 0) 
		{
			DB::customQuery("UPDATE repartitionCours SET occupation = occupation+1 
				WHERE idRepartitionCours=?",
				[$id]
			);
		} 
		else 
		{
			DB::customQuery("UPDATE repartitionCours SET occupation = occupation-1 
				WHERE idRepartitionCours=?",
				[$id]
			);
		}
	}

	/**
	 * Recuperer salle via term et niveau
	 * 
	 * */
	public function findSalleByNiveauAndTerm($idNiveau,$idTerm)
	{
		return DB::customQuery("SELECT * FROM repartitionCours 
			INNER JOIN salle ON salle.idSalle=repartitionCours.idSalle
			INNER JOIN horaireCours ON horaireCours.idHoraireCours=repartitionCours.idHoraireCours
			WHERE idNiveau=?
			AND idTerm=?",
			[$idNiveau,$idTerm]
		);
	}

}