<?php 

class RepartitionPTModel extends CI_Model{

	public function getAll()
	{
		return DB::customQuery("SELECT repartitionPT.*,
			term.nomTerm,exercice.anneeExercice,
			horairePT.debutPT,horairePT.finPT,
			enseignant.nomEnseignant,enseignant.prenomEnseignant,
			salle.nomSalle,
			matierePT.nomMatierePT 
			FROM repartitionPT 
			INNER JOIN matierePT ON matierePT.idMatierePT=repartitionPT.idMatierePT
			INNER JOIN session ON session.idSession=repartitionPT.idSession
			INNER JOIN term ON session.idTerm=term.idTerm
			INNER JOIN exercice ON term.idExercice=exercice.idExercice
			INNER JOIN horairePT ON horairePT.idHorairePT=repartitionPT.idHorairePT
			INNER JOIN enseignant ON enseignant.matriculeEnseignant=repartitionPT.matriculeEnseignant
			INNER JOIN salle ON salle.idSalle=repartitionPT.idSalle
			ORDER BY session.idSession DESC");
	}

	public function getAllSearch($query)
	{
		return DB::customQuery("SELECT repartitionPT.*,
			term.nomTerm,exercice.anneeExercice,
			horairePT.debutPT,horairePT.finPT,
			enseignant.nomEnseignant,enseignant.prenomEnseignant,
			salle.nomSalle,
			matierePT.nomMatierePT 
			FROM repartitionPT 
			INNER JOIN matierePT ON matierePT.idMatierePT=repartitionPT.idMatierePT
			INNER JOIN session ON session.idSession=repartitionPT.idSession
			INNER JOIN term ON session.idTerm=term.idTerm
			INNER JOIN exercice ON term.idExercice=exercice.idExercice
			INNER JOIN horairePT ON horairePT.idHorairePT=repartitionPT.idHorairePT
			INNER JOIN enseignant ON enseignant.matriculeEnseignant=repartitionPT.matriculeEnseignant
			INNER JOIN salle ON salle.idSalle=repartitionPT.idSalle
			WHERE exercice.anneeExercice LIKE ?
			OR term.nomTerm LIKE ?
			OR enseignant.nomEnseignant LIKE ?
			OR enseignant.prenomEnseignant LIKE ?
			OR matierePT.nomMatierePT LIKE ?
			OR repartitionPT.dateTest LIKE ?
			OR salle.nomSalle LIKE ?
			ORDER BY session.idSession DESC",
			[$query,$query,$query,$query,$query,$query,$query]
		);
	}

	public function getOne($id)
	{
		return DB::select("repartitionPT")
					->where("idRepartitionPT","=")
					->fetchOne([$id]);
	}

	public function create($fields,$values)
	{
		DB::insert("repartitionPT")
			->parametters($fields)
			->execute($values);
	}
	public function update($fields,$values)
	{
		DB::update("repartitionPT")
			->parametters($fields)
			->where("idRepartitionPT","=")
			->execute($values);
	}

	public function delete($id)
	{
		DB::delete("repartitionPT")
			->where("idRepartitionPT","=")
			->execute([$id]);
	}

	/**
	 * 
	 * Verification doublon
	 * 
	 * */
	public function isExist($session,$matiere,$date,$heure,$enseignant,$salle)
	{
		$res = DB::customQuery("SELECT * FROM repartitionPT
			WHERE idSession=?
			AND idMatierePT=?
			AND dateTest=?
			AND idHorairePT=?
			AND matriculeEnseignant=?
			AND idSalle=?",
			[$session,$matiere,$date,$heure,$enseignant,$salle],
			false
		);

		if($res)
			return true;
		return false;
	}

	/**
	 * Recupere les dates de test via session
	 * 
	 * */
	public function getDateBySession($idSession)
	{
		return DB::customQuery("SELECT DISTINCT dateTest FROM repartitionPT WHERE idSession=?",[$idSession]);
	}

	public function getSalles($idSession,$dateTest,$matiere)
	{
		return DB::customQuery("SELECT repartitionPT.idRepartitionPT,salle.* FROM repartitionPT
			INNER JOIN salle ON salle.idSalle=repartitionPT.idSalle
			INNER JOIN matierePT ON matierePT.idMatierePT=repartitionPT.idMatierePT
			WHERE repartitionPT.idSession=?
			AND repartitionPT.dateTest=?
			AND matierePT.nomMatierePT=?",
			[$idSession,$dateTest,$matiere]
		);
	}

	/**
	 * Recupere l'heure de test ecrit
	 * 
	 * */
	public function getHeureEcrit($salleEcrit)
    {
        $res = DB::customQuery("SELECT * FROM repartitionPT
        	INNER JOIN horairePT ON horairePT.idHorairePT=repartitionPT.idHorairePT 
        	WHERE idRepartitionPT=?", 
        	[$salleEcrit],false
        );
        return $res->debutPT;
    }
    /**
     * 
     * Generer l'heure de test orale
     * 
     * */
    public function getHeureOral($date, $salleOral)
    {
        $inspt = DB::customQuery("SELECT * FROM inscriptionPT 
        	WHERE dateTest=? AND salleOral=? ORDER BY idInscriptionPT DESC",[$date,$salleOral], false);
        $heure = null;

        if (!$inspt) 
        {
            $res = DB::customQuery("SELECT * FROM repartitionPT 
            	INNER JOIN horairePT ON horairePT.idHorairePT=repartitionPT.idHorairePT
            	WHERE idRepartitionPT=?",
            	[$salleOral], false
            );
            $heure = $res->debutPT;
        } 
        else 
        {
            $last = $inspt->heureOral;
            $parts = explode(":", $last);
            $matierePT = DB::customQuery("SELECT matierePT.* FROM repartitionPT
            	INNER JOIN matierePT ON matierePT.idMatierePT=repartitionPT.idMatierePT
            	WHERE idRepartitionPT=?",
            	[$salleOral],false
            );

            $minutes = ((int)$parts[0] * 60) + (int)$parts[1] + (int)$matierePT->dureeMatierePT;
            $heure = str_pad(floor($minutes / 60), 2, "0", STR_PAD_LEFT) . ":" . str_pad(($minutes % 60), 2, "0", STR_PAD_LEFT);
        }

        return $heure;
    }

    /**
     * 
     * Mettre à jour occupation salle
     * 
     * */
    public function updateOccupationSalle($idRepartition, $n = 1)
	{
		if ($n > 0) {
			DB::customQuery("UPDATE repartitionPT SET occupation = occupation + 1 WHERE idRepartitionPT=?",[$idRepartition]);
		} else {
			DB::customQuery("UPDATE repartitionPT SET occupation = occupation - 1 WHERE idRepartitionPT=?",[$idRepartition]);
		}
	}

	/**
	 * Recuperer les salles encore disponible
	 * 
	 * */
	public function getSalleDispo($dateExamen, $matiere)
	{
		if ($matiere === "Ecrit") 
		{
			return DB::customQuery("SELECT salle.*,repartitionPT.idRepartitionPT 
				FROM repartitionPT 
				INNER JOIN salle ON salle.idSalle=repartitionPT.idSalle 
				INNER JOIN matierePT ON matierePT.idMatierePT=repartitionPT.idMatierePT
				WHERE dateTest=? 
				AND nomMatierePT=? 
				AND occupation<capaciteSalle",
				[$dateExamen,$matiere]
			);
		}

		$salles = DB::customQuery("SELECT * FROM repartitionPT
			INNER JOIN horairePT ON horairePT.idHorairePT=repartitionPT.idHorairePT  
			INNER JOIN matierePT ON matierePT.idMatierePT=repartitionPT.idMatierePT
			WHERE dateTest=? 
			AND nomMatierePT=? 
			GROUP BY idSalle,debutPT",
			[$dateExamen,$matiere]
		);

		if (empty($salles)) 
		{
			return DB::customQuery("SELECT salle.*,horairePT.*,repartitionPT.idRepartitionPT 
				FROM repartitionPT 
				INNER JOIN horairePT ON horairePT.idHorairePT=repartitionPT.idHorairePT
				INNER JOIN salle ON salle.idSalle=repartitionPT.idSalle 
				INNER JOIN matierePT ON matierePT.idMatierePT=repartitionPT.idMatierePT
				WHERE dateTest=? 
				AND nomMatierePT=?",
				[$dateExamen,$matiere]
			);
		}

		$heuresMax = [];

		foreach ($salles as $salle) 
		{
			$res = DB::customQuery("SELECT * FROM inscriptionPT 
				WHERE salleOral=? 
				ORDER BY heureOral DESC LIMIT 1",
				[$salle->idRepartitionPT], false
			);

			if ($res) 
			{
				$heuresMax[] = (object)[
					"max" => $res->heureOral,
					"idRepartitionPT" => $res->salleOral
				];
			} 
			else 
			{
				$heuresMax[] = (object)[
					"max" => $salle->debutPT,
					"idRepartitionPT" => $salle->idRepartitionPT
				];
			}
		}
		$allSalles = DB::customQuery("SELECT salle.*,repartitionPT.*,horairePT.*
			FROM repartitionPT INNER JOIN salle ON salle.idSalle=repartitionPT.idSalle
			INNER JOIN matierePT ON matierePT.idMatierePT=repartitionPT.idMatierePT 
			INNER JOIN horairePT ON horairePT.idHorairePT=repartitionPT.idHorairePT
			WHERE dateTest=? 
			AND nomMatierePT=?",
			[$dateExamen,$matiere]
		);

		$sallesDispo = [];
		foreach ($allSalles as $k => $salle) 
		{
			foreach ($heuresMax as $heure) {
				if ($heure->max >= $salle->finPT && $salle->idRepartitionPT === $heure->idRepartitionPT) {
					unset($allSalles[$k]);
				}
			}
		}
		return array_values($allSalles);
	}

	/**
	 * Recuperer une salle via cle primaire
	 * 
	 * */
	public function getSalleById($id)
	{
		return DB::customQuery("SELECT repartitionPT.idRepartitionPT,salle.*
			FROM repartitionPT
			INNER JOIN salle ON salle.idSalle=repartitionPT.idSalle
			WHERE idRepartitionPT=?",
			[$id],false
		);
	}


}