<?php 

class Frais extends CI_Controller{


	public function __construct()
	{
		parent::__construct();
		$this->load->model("FraisModel","frais");
		$this->load->model("ClasseModel","classe");
		$this->load->model("NiveauModel","niveau");
		$this->load->model("CategorieClasseModel","categorie");
	}

	public function index($action="create",$values=null)
	{
		$data["active"] = 4;
		$data["action"] = $action;
		$data["lists"] = $this->frais->getAll();

		$classes = $this->classe->getAll();
		$data["classes"] = $classes;

		$niveaux = [];
		$categories = [];
		$data["joursCours"] = [];

		if(!empty($classes))
		{
			$niveaux = $this->niveau->getByClasse($classes[0]->idClasse);
		}
		$data["niveaux"] = $niveaux;

		if(!empty($niveaux))
		{
			if($this->niveau->hasCategorie($niveaux[0]->idNiveau))
			{
				$categories = $this->categorie->getAll();
			}

			$data["joursCours"] = explode("|", $niveaux[0]->joursCours);
		}
		$data["categories"] = $categories;

		if($values)
		{
			$data["values"] = $values;
		}

		$this->load->view("parametrage/frais",$data);
	}

	/**
	 * 
	 * Rafraichir le formulaire lorsque la classe change
	 * 
	 * */
	public function getInfoByClasse()
	{
		$idClasse = (int)$_POST["idClasse"];

		$data["classes"] = $this->classe->getAll();

		$categories = [];
		$data["joursCours"] = [];

		$niveaux = $this->niveau->getByClasse($idClasse);
		$data["niveaux"] = $niveaux;

		if(!empty($niveaux))
		{
			if($this->niveau->hasCategorie($niveaux[0]->idNiveau))
			{
				$categories = $this->categorie->getAll();
			}

			$data["joursCours"] = explode("|", $niveaux[0]->joursCours);
		}
		$data["categories"] = $categories;
		$data["values"] = ["classe" => $idClasse];

		$this->load->view("parametrage/components/form_frais",$data);
	}

	/**
	 * 
	 * Rafraichir le formulaire lorsque le niveau change
	 * 
	 * */
	public function getInfoByNiveau()
	{
		$idNiveau = (int)$_POST["niveau"];
		$classe = (int)$_POST["classe"];

		$data["classes"] = $this->classe->getAll();

		$categories = [];
		$data["joursCours"] = [];

		$niveaux = $this->niveau->getByClasse($classe);
		$data["niveaux"] = $niveaux;

		if(!empty($niveaux))
		{
			if($this->niveau->hasCategorie($idNiveau))
			{
				$categories = $this->categorie->getAll();
			}

			$data["joursCours"] = $this->niveau->getJoursCours($idNiveau);
		}
		$data["categories"] = $categories;
		$data["values"] = ["classe" => $classe,"niveau" => $idNiveau];

		$this->load->view("parametrage/components/form_frais",$data);
	}

	/**
	 * 
	 * Renvoyer les donnée lorsque on a une erreur de validation des donnée
	 * 
	 * */
	public function formError($action="create",$values=null)
	{
		$data["active"] = 4;
		$data["action"] = $action;
		$data["lists"] = $this->frais->getAll();

		$classes = $this->classe->getAll();
		$data["classes"] = $classes;
		
		$idNiveau = 0;
		if(isset($values["niveau"]))
		{
			$idNiveau = (int)$values["niveau"];
		}

		$categories = [];


		$data["niveaux"] = $this->niveau->getByClasse((int)$values["classe"]);


		if($this->niveau->hasCategorie($idNiveau))
		{
			$categories = $this->categorie->getAll();
		}

		$data["joursCours"] = $this->niveau->getJoursCours($idNiveau);

		$data["categories"] = $categories;

		if($values)
		{
			$data["values"] = $values;
		}

		$this->load->view("parametrage/frais",$data);
	}

	/**
	 * Reinitialisation du formulaire apres insertion/update
	 * 
	 * 
	 * */
	public function resetForm($action="create",$values=null)
	{
		$data["active"] = 4;
		$data["action"] = $action;
		$data["lists"] = $this->frais->getAll();

		$classes = $this->classe->getAll();
		$data["classes"] = $classes;

		$niveaux = $this->niveau->getByClasse((int)$values["classe"]);
		$data["niveaux"] = $niveaux;

		$categories = [];

		if($this->niveau->hasCategorie($niveaux[0]->idNiveau))
		{
			$categories = $this->categorie->getAll();
		}

		$data["joursCours"] = $this->niveau->getJoursCours($niveaux[0]->idNiveau);

		$data["categories"] = $categories;

		if($values)
		{
			$data["values"] = $values;
		}

		$this->load->view("parametrage/frais",$data);
	}


	/**
	 * Rafraichissement du formulaire pour update
	 * 
	 * 
	 * */
	public function formUpdate($values=null)
	{
		$data["active"] = 4;
		$data["action"] = "update";
		$data["lists"] = $this->frais->getAll();

		$classes = $this->classe->getAll();
		$data["classes"] = $classes;

		$niveaux = $this->niveau->getByClasse((int)$values["classe"]);
		$data["niveaux"] = $niveaux;

		$categories = [];

		if($this->niveau->hasCategorie( (int)$values["niveau"] ))
		{
			$categories = $this->categorie->getAll();
		}

		$data["joursCours"] = $this->niveau->getJoursCours( (int)$values["niveau"] );

		$data["categories"] = $categories;

		if($values)
		{
			$data["values"] = $values;
		}

		$this->load->view("parametrage/frais",$data);
	}

	public function create()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules("classe","classe","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("niveau","niveau","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("jours","jours","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("montant","montant","required",["required" => "Ce champ est obligatoire"]);

		if(!$this->form_validation->run())
		{
			$this->formError("create",$_POST);
			return false;
		}

		$niveau = (int)$_POST["niveau"];
		$montant = (int)$_POST["montant"];
		$jours = trim($_POST["jours"]);
		$categorie = null;

		if(isset($_POST['categorie']))
		{
			$this->form_validation->set_rules("categorie","categorie","required",["required" => "Ce champ est obligatoire"]);
			if(!$this->form_validation->run())
			{
				$this->formError("create",$_POST);
				return false;
			}
			$categorie = (int)$_POST["categorie"];
		}

		if($this->frais->isExist($niveau,$jours,$categorie))
		{
			$this->formError("create",array_merge($_POST,Utility::getAlert("error","Frais déjà enregistré pour cette combinaison")));
			return false;
		}

		$this->frais->create(["idNiveau","montant","idCategorie","joursCours"],[$niveau,$montant,$categorie,$jours]);
		$this->resetForm("create",array_merge(["classe" => (int)$_POST["classe"]],Utility::getAlert("success")));
	}

	public function getOne()
	{
		$id = (int)$_POST["id"];
		$res = $this->frais->getOne($id);

		$this->formUpdate([
			"id" => $res->idFrais,
			"niveau" => $res->idNiveau,
			"montant" => $res->montant,
			"jours" => $res->joursCours,
			"categorie" => $res->idCategorie,
			"classe" => $res->idClasse
		]);
	}

	public function update()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules("montant","montant","required",["required" => "Ce champ est obligatoire"]);

		$id = (int)$_POST["id"];
		$montant = (int)$_POST["montant"];

		$res = $this->frais->getOne($id);

		if(!$this->form_validation->run())
		{
			$this->formError("update",[
				"id" => $res->idFrais,
				"niveau" => $res->idNiveau,
				"montant" => $_POST['montant'],
				"jours" => $res->joursCours,
				"categorie" => $res->idCategorie,
				"classe" => $res->idClasse
			]);
			return false;
		}

		$this->frais->update(["montant"],[$montant,$id]);
		$this->index("create",Utility::getAlert("success"));
	}

	public function delete()
	{
		$id = (int)$_POST["id"];
		$this->frais->delete($id);
		$this->index("create",Utility::getAlert("success","Frais supprimé"));	
	}

	public function filter()
	{
		$query = trim($_POST["query"]);
		if($query === "")
		{
			$this->index();
			return false;
		}

		$data["active"] = 4;
		$data["action"] = "create";
		$data["lists"] = $this->frais->getAllSearch("%".$query."%");

		$classes = $this->classe->getAll();
		$data["classes"] = $classes;

		$niveaux = [];
		$categories = [];
		$data["joursCours"] = [];

		if(!empty($classes))
		{
			$niveaux = $this->niveau->getByClasse($classes[0]->idClasse);
		}
		$data["niveaux"] = $niveaux;

		if(!empty($niveaux))
		{
			if($this->niveau->hasCategorie($niveaux[0]->idNiveau))
			{
				$categories = $this->categorie->getAll();
			}

			$data["joursCours"] = explode("|", $niveaux[0]->joursCours);
		}
		$data["categories"] = $categories;

		$data["query"] = $query;

		$this->load->view("parametrage/frais",$data);
	}

}