<?php 

class ResultatPT extends CI_Controller{

	public function __construct()
	{
		parent::__construct();
		$this->load->model("ResultatPTModel","resultat");
		$this->load->model("SessionModel","msession");
		$this->load->model("EtudiantPTModel","etudiantPT");
	}

	public function index($action="create",$values=null,$page=1)
	{
		$data["active"] = 1;
		$data["action"] = $action;
		$offset = ($page - 1) * LIMIT_PAGINATION;
		$data["lists"] = $this->resultat->getAll($offset);

		if($values)
		{
			$data["values"] = $values;
		}

		$data["totals"] = $this->resultat->getCount();
		$data["currentPage"] = $page;

		$data["sessions"] = $this->msession->getAll();

		$this->load->view("test/resultat",$data);
	}

	public function page($number)
	{
		$page = (int)$number;
		if($page <= 0)
		{
			$page = 1;
		}

		if(isset($_GET["query"]))
		{
			$query = htmlspecialchars(trim($_GET['query']));
			$total = $this->resultat->getCountSearch("%" .$query."%");
			$npages = ceil($total/LIMIT_PAGINATION);

			if($page > $npages)
			{
				$page = $npages;
			}
			$_POST['query'] = $query;
			$this->filter($page);
		}
		else
		{
			$total = $this->resultat->getCount();
			$npages = ceil($total/LIMIT_PAGINATION);

			if($page > $npages)
			{
				$page = $npages;
			}
			$this->index("create",null,$page);
		}
	}

	public function create()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules("session","session","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("score-ecrit","score-ecrit","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("rating-oral","rating-oral","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("numeroPT","numeroPT","required",["required" => "Ce champ est obligatoire"]);

		if(!$this->form_validation->run())
		{
			$this->index("create",$_POST);
			return false;
		}

		$session = (int)$_POST['session'];

		$numero = (int)$_POST["numeroPT"] . "";
		$first = $numero[0];
		$numeroPT = $numero . "/PT/T" . $first;

		$scoreEcrit = (int)$_POST['score-ecrit'];
		$ratingOral = (int)$_POST["rating-oral"];

		$etu = $this->etudiantPT->getOne($numeroPT);


		if(!$etu)
		{
			$this->form_validation->set_rules("numeroPT","numeroPT","in_list[x01x02x03x04x05fd9a]",[
				"in_list" => "Etudiant inexistant"
			]);
			$this->form_validation->run();
			$this->index("create",$_POST);
			return false;
		}

		if($session !== (int)$etu->idSession)
		{
			$this->index("create",array_merge($_POST,Utility::getAlert("error","Etudiant non inscrit à cette session")));
			return false;
		}

		if($this->resultat->isExist($numeroPT))
		{
			$this->index("create",array_merge($_POST,Utility::getAlert("error","Resultat déjà enregistré")));
			return false;
		}

		$codeClasse = $etu->codeClass;
		/**
		 * On recupere le rating ecrit
		 * 
		 * */
		$ratingEcrit = $this->resultat->getRatingEcrit($codeClasse,$scoreEcrit);

		$idNiveau = $this->resultat->getNiveau($ratingEcrit,$ratingOral,$codeClasse);

		if(!$idNiveau)
		{
			$moyenne = floor(($ratingEcrit + $ratingOral) / 2);
			$this->index("create",array_merge($_POST,Utility::getAlert("error","Aucune niveau défini pour la classe $codeClasse avec une rating de $moyenne")));
			return false;
		}

		$this->resultat->create(["numeroPT","idSession","scoreEcrit","ratingEcrit","ratingOral","idNiveau"],[$numeroPT,$session,$scoreEcrit,$ratingEcrit,$ratingOral,$idNiveau]);
		$this->index("create",Utility::getAlert("success"));
		
	}

	public function getOne()
	{
		$id = (int)$_POST["id"];
		$res = $this->resultat->getOne($id);

		$this->index("update",[
			"id" => $res->idResultatPT,
			"numeroPT" => $res->numeroPT,
			"fullname" => $res->nom . " " . $res->prenom,
			"session" => $res->idSession,
			"score-ecrit" => $res->scoreEcrit,
			"rating-oral" => $res->ratingOral
		]);
	}

	public function update()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules("session","session","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("score-ecrit","score-ecrit","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("rating-oral","rating-oral","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("numeroPT","numeroPT","required",["required" => "Ce champ est obligatoire"]);

		if(!$this->form_validation->run())
		{
			$this->index("update",$_POST);
			return false;
		}

		$session = (int)$_POST['session'];

		$numero = (int)$_POST["numeroPT"] . "";
		$first = $numero[0];
		$numeroPT = $numero . "/PT/T" . $first;

		$scoreEcrit = (int)$_POST['score-ecrit'];
		$ratingOral = (int)$_POST["rating-oral"];
		$id = (int)$_POST["id"];

		$etu = $this->etudiantPT->getOne($numeroPT);


		if(!$etu)
		{
			$this->form_validation->set_rules("numeroPT","numeroPT","in_list[x01x02x03x04x05fd9a]",[
				"in_list" => "Etudiant inexistant"
			]);
			$this->form_validation->run();
			$this->index("update",$_POST);
			return false;
		}

		if($session !== (int)$etu->idSession)
		{
			$this->index("update",array_merge($_POST,Utility::getAlert("error","Etudiant non inscrit à cette session")));
			return false;
		}

		$toUpdate = $this->resultat->getOne($id);

		if($scoreEcrit !== (int)$toUpdate->scoreEcrit || $ratingOral !== (int)$toUpdate->ratingOral)
		{

			$codeClasse = $etu->codeClass;
			/**
			 * On recupere le rating ecrit
			 * 
			 * */
			$ratingEcrit = $this->resultat->getRatingEcrit($codeClasse,$scoreEcrit);

			$idNiveau = $this->resultat->getNiveau($ratingEcrit,$ratingOral,$codeClasse);

			if(!$idNiveau)
			{
				$moyenne = floor(($ratingEcrit + $ratingOral) / 2);
				$this->index("update",array_merge($_POST,Utility::getAlert("error","Aucune niveau défini pour la classe $codeClasse avec une rating de $moyenne")));
				return false;
			}

			$this->resultat->update(["scoreEcrit","ratingEcrit","ratingOral","idNiveau"],[$scoreEcrit,$ratingEcrit,$ratingOral,$idNiveau,$id]);
		}

		$this->index("create",Utility::getAlert("success"));
		
	}

	public function filter($page=1)
	{
		$query = trim($_POST['query']);
		if($query === "")
		{
			$this->index();
			return false;
		}
		$data["active"] = 1;
		$data["action"] = "create";
		$offset = ($page - 1) * LIMIT_PAGINATION;
		$data["lists"] = $this->resultat->getAllSearch("%".$query."%",$query);

		$data["query"] = $query;

		$data["sessions"] = $this->msession->getAll();

		$data["totals"] = $this->resultat->getCountSearch("%".$query."%");
		$data["currentPage"] = $page;

		$this->load->view("test/resultat",$data);
	}

	public function delete()
	{
		$id = (int)$_POST["id"];
		$this->resultat->delete($id);
		$this->index("create",Utility::getAlert("success","Resultat supprimé"));
	}

	public function export()
	{
		$all = $this->resultat->getAll();
		$data = [];
		foreach ($all as $value) {
			$data[] = (object)[
				"Session" => $value->anneeExercice . " - " . $value->nomTerm,
				"Numéro PT" => $value->numeroPT,
				"Classe" => $value->codeClasse,
				"Niveau" => $value->codeNiveau,
				"Nom & prénoms" => $value->nom . " " . $value->prenom,
				"Contact" => $value->contact,
				"Email" => $value->email
			];
		}
		ExportExcel::exporter('ResultatPT', $data);
	}
}