<?php 

class Company extends CI_Controller{

	public function __construct()
	{
		parent::__construct();
		if(!isset($_SESSION['userID'])){
			redirect(base_url("login"));
            exit;
		}
		$this->load->model("CompanyModel","company");
	}

	public function index($action="create",$values=null)
	{
		$data["active"] = 1;
		$data["action"] = $action;
		$data["lists"] = $this->company->getAll();

		if($values)
		{
			$data["values"] = $values;
		}

		$this->load->view("parametrage/company",$data);
	}

	public function create()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules("nom","nom","required|is_unique[company.nomCompany]",[
			"required" => "Ce champ est obligatoire",
			"is_unique" => "Ce compagnie est déjà enregistré"
		]);
		if(!$this->form_validation->run())
		{
			$this->index("create",$_POST);
			return false;
		}

		$nom = trim($_POST["nom"]);
		$contact = trim($_POST["contact"]);
		$adresse = trim($_POST["adresse"]);
		$responsable = trim($_POST["responsable"]);

		$this->company->create(["nomCompany","adresseCompany","contactCompany","responsableCompany"],[$nom,$adresse,$contact,$responsable]);
		$this->index("create",Utility::getAlert("success"));
	}

	public function getOne()
	{
		$id = (int)$_POST["id"];

		$res = $this->company->getOne($id);
		$this->index("update",[
			"id" => $res->idCompany,
			"nom" => $res->nomCompany,
			"adresse" => $res->adresseCompany,
			"contact" => $res->contactCompany,
			"responsable" => $res->responsableCompany
		]);
	}

	public function update()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules("nom","nom","required",[
			"required" => "Ce champ est obligatoire"
		]);
		if(!$this->form_validation->run())
		{
			$this->index("update",$_POST);
			return false;
		}

		$nom = trim($_POST["nom"]);
		$contact = trim($_POST["contact"]);
		$adresse = trim($_POST["adresse"]);
		$responsable = trim($_POST["responsable"]);
		$id = (int)$_POST["id"];

		$toUpdate = $this->company->getOne($id);
		if($nom !== $toUpdate->nomCompany)
		{
			$this->form_validation->set_rules("nom","nom","is_unique[company.nomCompany]",[
				"is_unique" => "Ce compagnie est déjà enregistré"
			]);
			if(!$this->form_validation->run())
			{
				$this->index("update",$_POST);
				return false;
			}
		}

		$this->company->update(["nomCompany","adresseCompany","contactCompany","responsableCompany"],[$nom,$adresse,$contact,$responsable,$id]);
		$this->index("create",Utility::getAlert("success"));
	}

	public function delete()
	{
		$id = (int)$_POST["id"];
		$this->company->delete($id);
		$this->index("create",Utility::getAlert("success","Compagnie supprimé"));
	}

	public function filter()
	{
		$query = trim($_POST["query"]);
		if($query === "")
		{
			$this->index("create");
			return false;
		}

		$data["active"] = 1;
		$data["action"] = "create";
		$data["lists"] = $this->company->getAllSearch("%".$query."%");

		$data["query"] = $query;

		$this->load->view("parametrage/company",$data);
	}


}