<?php 

class Exercice extends CI_Controller{

	public function __construct()
	{
		parent::__construct();
		if(!isset($_SESSION['userID'])){
			redirect(base_url("login"));
            exit;
		}
		$this->load->model("ExerciceModel",'exercice');
	}

	public function index($action="create",$values=null)
	{
		$data["active"] = 1;
		$data["action"] = $action;
		$data["lists"] = $this->exercice->getAll();

		if($values)
		{
			$data["values"] = $values;
		}

		$this->load->view("parametrage/exercice",$data);
	}

	public function create()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules("annee","annee","required|is_unique[exercice.anneeExercice]",[
			"required" => "Ce champ est obligatoire",
			"is_unique" => "L'année doit être unique"
		]);
		$this->form_validation->set_rules("debut","debut","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("fin","fin","required",["required" => "Ce champ est obligatoire"]);

		if(!$this->form_validation->run())
		{
			$this->index("create",$_POST);
			return false;
		}

		$annee = (int)$_POST["annee"];
		$debut = trim($_POST["debut"]);
		$fin = trim($_POST["fin"]);

		$this->exercice->create(["anneeExercice","debutExercice","finExercice"],[$annee,$debut,$fin]);
		$this->index("create",Utility::getAlert("success"));
	}

	public function getOne()
	{
		$id = (int)$_POST["id"];
		$res = $this->exercice->getOne($id);
		$this->index("update",[
			"id" => $res->idExercice,
			"annee" => $res->anneeExercice,
			"debut" => $res->debutExercice,
			"fin" => $res->finExercice
		]);
	}

	public function update()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules("annee","annee","required",[
			"required" => "Ce champ est obligatoire"
		]);
		$this->form_validation->set_rules("debut","debut","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("fin","fin","required",["required" => "Ce champ est obligatoire"]);

		if(!$this->form_validation->run())
		{
			$this->index("update",$_POST);
			return false;
		}

		$annee = (int)$_POST["annee"];
		$debut = trim($_POST["debut"]);
		$fin = trim($_POST["fin"]);
		$id = (int)$_POST["id"];

		$toUpdate = $this->exercice->getOne($id);
		if($annee !== (int)$toUpdate->anneeExercice)
		{
			$this->form_validation->set_rules("annee","annee","is_unique[exercice.anneeExercice]",[
				"is_unique" => "L'année doit être unique"
			]);

			if(!$this->form_validation->run())
			{
				$this->index("update",$_POST);
				return false;
			}
		}

		$this->exercice->update(["anneeExercice","debutExercice","finExercice"],[$annee,$debut,$fin,$id]);
		$this->index("create",Utility::getAlert("success"));
	}

	public function delete()
	{
		$id = (int)$_POST["id"];
		$this->exercice->delete($id);
		$this->index("create",Utility::getAlert("success","Exercice supprimé"));
	}

	public function filter()
	{
		$query = trim($_POST["query"]);
		if($query === "")
		{
			$this->index("create");
			return false;
		}

		$data["active"] = 1;
		$data["action"] = "create";
		$data["lists"] = $this->exercice->getAllSearch("%".$query."%");

		$data["query"] = $query;

		$this->load->view("parametrage/exercice",$data);
	}
}