<?php 

class Matiere extends CI_Controller{

	public function __construct()
	{
		parent::__construct();
		if(!isset($_SESSION['userID'])){
			redirect(base_url("login"));
            exit;
		}
		$this->load->model("MatiereModel","matiere");
	}

	public function index($action="create",$values=null)
	{
		$data["active"] = 1;
		$data["action"] = $action;
		$data["lists"] = $this->matiere->getAll();

		if($values)
		{
			$data["values"] = $values;
		}

		$this->load->view("parametrage/matiere",$data);
	}

	public function create()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules("nom","nom","required|is_unique[matiere.nomMatiere]",[
			"required" => "Ce champ est obligatoire",
			"is_unique" => "Ce matière est déjà enregistré"
		]);
		$this->form_validation->set_rules("alias","alias","required|is_unique[matiere.nomMatiere]",[
			"required" => "Ce champ est obligatoire",
			"is_unique" => "Cet alias est déjà utilisé"
		]);

		if(!$this->form_validation->run())
		{
			$this->index("create",$_POST);
			return false;
		}

		$nom = trim($_POST['nom']);
		$alias = trim($_POST["alias"]);

		$this->matiere->create(["nomMatiere","aliasMatiere"],[$nom,$alias]);
		$this->index("create",Utility::getAlert("success"));
	}

	public function getOne()
	{
		$id = (int)$_POST["id"];
		$res = $this->matiere->getOne($id);
		$this->index("update",[
			"id" => $res->idMatiere,
			"nom" => $res->nomMatiere,
			"alias" => $res->aliasMatiere
		]);
	}

	public function update()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules("nom","nom","required",[
			"required" => "Ce champ est obligatoire"
		]);
		$this->form_validation->set_rules("alias","alias","required",[
			"required" => "Ce champ est obligatoire"
		]);

		if(!$this->form_validation->run())
		{
			$this->index("update",$_POST);
			return false;
		}

		$nom = trim($_POST['nom']);
		$alias = trim($_POST["alias"]);
		$id = (int)$_POST["id"];

		$toUpdate = $this->matiere->getOne($id);
		if($nom !== $toUpdate->nomMatiere)
		{
			$this->form_validation->set_rules("nom","nom","is_unique[matiere.nomMatiere]",[
				"is_unique" => "Ce matière est déjà enregistré"
			]);

			if(!$this->form_validation->run())
			{
				$this->index("update",$_POST);
				return false;
			}
		}
		if($alias !== $toUpdate->aliasMatiere)
		{
			$this->form_validation->set_rules("alias","alias","is_unique[matiere.nomMatiere]",[
				"is_unique" => "Cet alias est déjà utilisé"
			]);

			if(!$this->form_validation->run())
			{
				$this->index("update",$_POST);
				return false;
			}
		}

		$this->matiere->update(["nomMatiere","aliasMatiere"],[$nom,$alias,$id]);
		$this->index("create",Utility::getAlert("success"));
	}
	public function delete()
	{
		$id = (int)$_POST["id"];
		$this->matiere->delete($id);
		$this->index("create",Utility::getAlert("success","Matière supprimé"));
	}

	public function filter()
	{
		$query = trim($_POST["query"]);

		if($query === "")
		{
			$this->index("create");
			return false;
		}

		$data["active"] = 1;
		$data["action"] = "create";
		$data["lists"] = $this->matiere->getAllSearch("%".$query."%");

		$data["query"] = $query;

		$this->load->view("parametrage/matiere",$data);
	}


}