<?php 

class Remise extends CI_Controller{

	public function __construct()
	{
		parent::__construct();
		if(!isset($_SESSION['userID'])){
			redirect(base_url("login"));
            exit;
		}
		$this->load->model("RemiseModel","remise");
	}

	public function index($action="create",$values=null)
	{
		$data["active"] = 1;
		$data["action"] = $action;
		$data["lists"] = $this->remise->getAll();

		if($values)
		{
			$data["values"] = $values;
		}
		$this->load->view("parametrage/remise",$data);
	}

	public function create()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules("designation","designation","required|is_unique[remise.nomRemise]",[
			"required" => "Ce champ est obligatoire",
			"is_unique" => "Ce nom existe déjà"
		]);
		$this->form_validation->set_rules("remise","remise","required",["required" => "Ce champ est obligatoire"]);

		if(!$this->form_validation->run())
		{
			$this->index("create",$_POST);
			return false;
		}

		$nom = trim($_POST["designation"]);
		$remise = (int)$_POST["remise"];

		$this->remise->create(["nomRemise","valueRemise"],[$nom,$remise]);
		$this->index("create",Utility::getAlert("success"));
	}

	public function getOne()
	{
		$id = (int)$_POST["id"];
		$res = $this->remise->getOne($id);
		$this->index("update",[
			"id" => $res->idRemise,
			"designation" => $res->nomRemise,
			"remise" => $res->valueRemise
		]);
	}

	public function update()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules("designation","designation","required",[
			"required" => "Ce champ est obligatoire",
		]);
		$this->form_validation->set_rules("remise","remise","required",["required" => "Ce champ est obligatoire"]);

		if(!$this->form_validation->run())
		{
			$this->index("update",$_POST);
			return false;
		}

		$nom = trim($_POST["designation"]);
		$remise = (int)$_POST["remise"];
		$id = (int)$_POST["id"];
		
		$toUpdate = $this->remise->getOne($id);
		if($toUpdate->nomRemise !== $nom)
		{
			$this->form_validation->set_rules("designation","designation","is_unique[remise.nomRemise]",[
				"is_unique" => "Ce nom existe déjà"
			]);
			if(!$this->form_validation->run())
			{
				$this->index("update",$_POST);
				return false;
			}
		}

		$this->remise->update(["nomRemise","valueRemise"],[$nom,$remise,$id]);
		$this->index("create",Utility::getAlert("success"));
	}

	public function delete()
	{
		$id = (int)$_POST["id"];
		$this->remise->delete($id);
		$this->index("create",Utility::getAlert("success","Remise supprimé"));
	}

	public function filter()
	{
		$query = trim($_POST["query"]);
		if($query === "")
		{
			$this->index("create");
			return false;
		}

		$data["active"] = 1;
		$data["action"] = "create";
		$data["lists"] = $this->remise->getAllSearch("%".$query."%");

		$data["query"] = $query;
		
		$this->load->view("parametrage/remise",$data);

	}
}