<?php 

class InscriptionCoursModel extends CI_Model{

	private $limit = LIMIT_PAGINATION;

	public function getNombre($terms, $niveaux, $salles )
	{
		return DB::customQuery("SELECT * FROM inscriptionCours
			WHERE inscriptionCours.idTerm = ? 
			AND inscriptionCours.idNiveau = ? 
			AND inscriptionCours.idSalle = ?  
			ORDER BY idInscriptionCours DESC",
			[$terms, $niveaux, $salles]
		);
	}

	public function getAll($offset=0)
	{
		return DB::customQuery("SELECT * FROM inscriptionCours
    		INNER JOIN etudiant ON etudiant.matricule=inscriptionCours.matriculeEtudiant
			LEFT JOIN term ON term.idTerm=inscriptionCours.idTerm
			LEFT JOIN exercice ON exercice.idExercice=term.idExercice
			LEFT JOIN niveau ON niveau.idNiveau=inscriptionCours.idNiveau
			LEFT JOIN classe ON niveau.idClasse=classe.idClasse
			LEFT JOIN horaireCours ON horaireCours.idHoraireCours=inscriptionCours.idHoraireCours
			LEFT JOIN company ON company.idCompany=etudiant.idCompany
			ORDER BY idInscriptionCours DESC
			LIMIT $this->limit OFFSET $offset
			");
	}

	public function getAllSearch($query,$offset=0)
	{
		return DB::customQuery("SELECT * FROM inscriptionCours
    		INNER JOIN etudiant ON etudiant.matricule=inscriptionCours.matriculeEtudiant
			LEFT JOIN term ON term.idTerm=inscriptionCours.idTerm
			LEFT JOIN exercice ON exercice.idExercice=term.idExercice
			LEFT JOIN niveau ON niveau.idNiveau=inscriptionCours.idNiveau
			LEFT JOIN classe ON niveau.idClasse=classe.idClasse
			LEFT JOIN horaireCours ON horaireCours.idHoraireCours=inscriptionCours.idHoraireCours
			LEFT JOIN company ON company.idCompany=etudiant.idCompany
			WHERE exercice.anneeExercice LIKE ?
			OR term.nomTerm LIKE ?
			OR inscriptionCours.matriculeEtudiant LIKE ?
			OR etudiant.nom LIKE ?
			OR etudiant.prenom LIKE ?
			OR classe.codeClasse LIKE ?
			OR niveau.codeNiveau LIKE ?
			ORDER BY idInscriptionCours DESC
			LIMIT $this->limit
			OFFSET $offset",
			[$query,$query,$query,$query,$query,$query,$query]
		);
	}

	public function getCount()
	{
		$res = DB::customQuery("SELECT COUNT(idInscriptionCours) AS count FROM inscriptionCours",[],false);
		return (int)$res->count;
	}
	public function getCountSearch($query)
	{
		$res = DB::customQuery("SELECT COUNT(idInscriptionCours) AS count FROM inscriptionCours
    		INNER JOIN etudiant ON etudiant.matricule=inscriptionCours.matriculeEtudiant
			LEFT JOIN term ON term.idTerm=inscriptionCours.idTerm
			LEFT JOIN exercice ON exercice.idExercice=term.idExercice
			LEFT JOIN niveau ON niveau.idNiveau=inscriptionCours.idNiveau
			LEFT JOIN classe ON niveau.idClasse=classe.idClasse
			LEFT JOIN horaireCours ON horaireCours.idHoraireCours=inscriptionCours.idHoraireCours
			LEFT JOIN company ON company.idCompany=etudiant.idCompany
			WHERE exercice.anneeExercice LIKE ?
			OR term.nomTerm LIKE ?
			OR inscriptionCours.matriculeEtudiant LIKE ?
			OR etudiant.nom LIKE ?
			OR etudiant.prenom LIKE ?
			OR classe.codeClasse LIKE ?
			OR niveau.codeNiveau LIKE ?",
			[$query,$query,$query,$query,$query,$query,$query],false
		);
		return (int)$res->count;
	}

	public function getAllWithCompany()
	{
		$res = DB::customQuery("SELECT inscriptionCours.*,company.*,
					term.nomTerm,exercice.anneeExercice 
					FROM inscriptionCours
    				INNER JOIN etudiant ON etudiant.matricule=inscriptionCours.matriculeEtudiant
                    INNER JOIN term ON inscriptionCours.idTerm=term.idTerm
                    INNER JOIN exercice ON exercice.idExercice=term.idExercice
                    INNER JOIN company ON etudiant.idCompany=company.idCompany
                    WHERE inscriptionCours.isValid=?
                    GROUP BY inscriptionCours.idTerm,etudiant.idCompany
                    ORDER BY idInscriptionCours DESC",
                    [1]
                );

        foreach ($res as $k => $r) {
            $res2 = DB::customQuery("
                SELECT COUNT(idInscriptionCours) AS count FROM inscriptionCours
    		INNER JOIN etudiant ON etudiant.matricule=inscriptionCours.matriculeEtudiant
                WHERE inscriptionCours.idTerm=? 
                AND etudiant.idCompany=?",
                [$r->idTerm,$r->idCompany],false
            );
            $res[$k]->count = $res2->count;
        }

        return $res;
	}

	public function getOne($id)
	{
		return DB::customQuery("SELECT inscriptionCours.*,
			term.idExercice,niveau.idClasse,niveau.joursCours as days,
			etudiant.nom,etudiant.prenom
			FROM inscriptionCours
			INNER JOIN term ON term.idTerm=inscriptionCours.idTerm
			INNER JOIN niveau ON niveau.idNiveau=inscriptionCours.idNiveau
    		INNER JOIN etudiant ON etudiant.matricule=inscriptionCours.matriculeEtudiant
			WHERE idInscriptionCours=?",
			[$id],false
		);
	}

	public function create($fields,$values)
	{
		DB::insert("inscriptionCours")
			->parametters($fields)
			->execute($values);
	}

	public function update($fields,$values)
	{
		DB::update("inscriptionCours")
			->parametters($fields)
			->where("idInscriptionCours","=")
			->execute($values);
	}

	public function delete($id)
	{
		DB::delete("inscriptionCours")
			->where("idInscriptionCours","=")
			->execute([$id]);
	}

	public function isExist($matriculeEtudiant,$term)
	{
		$res = DB::customQuery("SELECT * FROM inscriptionCours
			WHERE matriculeEtudiant=?
			AND idTerm=?",
			[$matriculeEtudiant,$term],false
		);

		if($res)
			return true;
		return false;

	}
	public function getByMatricule($matricule)
	{
		return DB::customQuery("SELECT * FROM inscriptionCours WHERE matriculeEtudiant=?",[$matricule],false);
	}
	/**
	 * 
	 * Recuperer les etudiant en salle
	 * 
	 * */
	public function getEtudiantByTermAndNiveau($niveau,$term)
	{
		return DB::select("inscriptionCours")
					->where("idNiveau","=")
					->and("idTerm","=")
					->and("joursCours","!=")
					->execute([$niveau,$term,"Online"]);
	}

	/**
	 * 
	 * Recuperer les etudiant en ligne
	 * 
	 * */
	public function getEtudiantByTermAndNiveauOnline($niveau,$term)
	{
		return DB::select("inscriptionCours")
					->where("idNiveau","=")
					->and("idTerm","=")
					->and("joursCours","=")
					->execute([$niveau,$term,"Online"]);
	}

	/**
	 * Recuperer les donnée du dernier inscription de l'etudiant
	 * 
	 * */
	public function getLastInscription($matricule)
	{
		return DB::customQuery("SELECT * FROM inscriptionCours
    		INNER JOIN etudiant ON etudiant.matricule=inscriptionCours.matriculeEtudiant
			WHERE inscriptionCours.matriculeEtudiant=?
			ORDER BY createdAt DESC",
			[$matricule],false
		);
	}

	/**
	 * Recuperer la derniere insertion
	 * 
	 * */
	public function getLastIdInserted()
	{
		$res = DB::customQuery("SELECT MAX(idInscriptionCours) AS max FROM inscriptionCours",[],false);

		return (int)$res->max;
	}

	/**
	 * Generer une nouvelle ffacture
	 * 
	 * */
	public function generateFacture($numeroFacture, $matricule)
    {
        DB::insert("factureCours")
            ->parametters(["numero", "matricule"])
            ->execute([$numeroFacture, $matricule]);
    }

	/***
	 * 
	 * Recuperer facture
	 * 
	 * */
	public function getRecu($id)
    {

        return DB::customQuery("SELECT factureCours.*,inscriptionCours.*,etudiant.*,
        	exercice.*,term.*,
        	salle.nomSalle,
        	horaireCours.debutCours,horaireCours.finCours,
        	classe.codeClasse,niveau.codeNiveau,
        	company.nomCompany,
        	remise.valueRemise
        	FROM factureCours
        	INNER JOIN inscriptionCours ON factureCours.numero=inscriptionCours.idInscriptionCours
    		INNER JOIN etudiant ON etudiant.matricule=inscriptionCours.matriculeEtudiant
        	LEFT JOIN company ON company.idCompany=etudiant.idCompany
        	INNER JOIN term ON term.idTerm=inscriptionCours.idTerm
        	INNER JOIN exercice ON exercice.idExercice=term.idExercice
        	LEFT JOIN horaireCours ON horaireCours.idHoraireCours=inscriptionCours.idHoraireCours
        	LEFT JOIN salle ON salle.idSalle=inscriptionCours.idSalle
        	LEFT JOIN remise ON remise.idRemise=inscriptionCours.idRemise
        	INNER JOIN niveau ON niveau.idNiveau=inscriptionCours.idNiveau
        	INNER JOIN classe ON classe.idClasse=niveau.idClasse
        	WHERE factureCours.numero=?",
        	[$id],false
        );
    }

    /**
     * 
     * recuperer etudiant company inscrit a une term
     * 
     * */
    public function getEtudiantsCompany($term,$company)
    {
    	return DB::customQuery("SELECT inscriptionCours.*,niveau.ordrePriorite 
    		FROM inscriptionCours 
    		INNER JOIN etudiant ON etudiant.matricule=inscriptionCours.matriculeEtudiant
    		INNER JOIN niveau ON niveau.idNiveau=inscriptionCours.idNiveau
    		WHERE inscriptionCours.idTerm=? 
    		AND etudiant.idCompany=?",
    		[$term,$company]
    	);
    }

    /**
     * Supprimer une facture
     * 
     * */
    public function deleteFacture($numero)
    {
    	DB::delete("factureCours")
    		->where("numero","=")
    		->execute([$numero]);
    }

    /**
     * 
     * Recherche des etudiants 
     * 
     * */
    public function findEtudiants($data)
    {
    	$conditions = "";
    	$values = [];

    	$i = 1;
    	$count = count($data);
    	foreach($data as $key => $value)
    	{
    		if($i < $count)
    		{
    			$conditions .= "$key=? AND ";	
    		}
    		else
    		{
    			$conditions .= "$key=?";
    		}
    		
    		$values[] = $value;

    		$i++;
    	}

    	$res = DB::customQuery("SELECT * FROM inscriptionCours
    		INNER JOIN etudiant ON etudiant.matricule=inscriptionCours.matriculeEtudiant
    		WHERE $conditions",
    		$values
    	);
    	
    	return $res;
    }


}